@@ -246,20 +246,12 @@ gs_flatpak_add_apps_from_xremote (GsFlatpak *self,
 	g_autofree gchar *appstream_fn = NULL;
 	g_autofree gchar *default_branch = NULL;
 	g_autofree gchar *only_app_id = NULL;
-	g_autoptr(AsProfileTask) ptask = NULL;
 	g_autoptr(AsStore) store = NULL;
 	g_autoptr(GFile) appstream_dir = NULL;
 	g_autoptr(GFile) file = NULL;
 	g_autoptr(GSettings) settings = NULL;
 	g_autoptr(GPtrArray) app_filtered = NULL;
 
-	/* profile */
-	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
-				  "%s::add-apps-from-remote{%s}",
-				  gs_flatpak_get_id (self),
-				  flatpak_remote_get_name (xremote));
-	g_assert (ptask != NULL);
-
 	/* get the AppStream data location */
 	appstream_dir = flatpak_remote_get_appstream_dir (xremote, NULL);
 	if (appstream_dir == NULL) {
@@ -376,19 +368,12 @@ gs_flatpak_rescan_installed (GsFlatpak *self,
 {
 	GPtrArray *icons;
 	const gchar *fn;
-	g_autoptr(AsProfileTask) ptask = NULL;
 	g_autoptr(GFile) path = NULL;
 	g_autoptr(GDir) dir = NULL;
 	g_autofree gchar *path_str = NULL;
 	g_autofree gchar *path_exports = NULL;
 	g_autofree gchar *path_apps = NULL;
 
-	/* profile */
-	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
-				  "%s::rescan-installed",
-				  gs_flatpak_get_id (self));
-	g_assert (ptask != NULL);
-
 	/* add all installed desktop files */
 	path = flatpak_installation_get_path (self->installation);
 	path_str = g_file_get_path (path);
@@ -461,15 +446,8 @@ gs_flatpak_rescan_appstream_store (GsFlatpak *self,
 				   GCancellable *cancellable,
 				   GError **error)
 {
-	g_autoptr(AsProfileTask) ptask = NULL;
 	g_autoptr(GPtrArray) xremotes = NULL;
 
-	/* profile */
-	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
-				  "%s::rescan-appstream",
-				  gs_flatpak_get_id (self));
-	g_assert (ptask != NULL);
-
 	/* remove all components */
 	as_store_remove_all (self->store);
 
@@ -585,17 +563,10 @@ gs_flatpak_refresh_appstream_remote (GsFlatpak *self,
 				     GError **error)
 {
 	g_autofree gchar *str = NULL;
-	g_autoptr(AsProfileTask) ptask = NULL;
 	g_autoptr(GsApp) app_dl = gs_app_new (gs_plugin_get_name (self->plugin));
 	g_autoptr(GsFlatpakProgressHelper) phelper = NULL;
 	g_autoptr(GError) local_error = NULL;
 
-	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
-				  "%s::refresh-appstream{%s}",
-				  gs_flatpak_get_id (self),
-				  remote_name);
-	g_assert (ptask != NULL);
-
 	/* TRANSLATORS: status text when downloading new metadata */
 	str = g_strdup_printf (_("Getting flatpak metadata for %s…"), remote_name);
 	gs_app_set_summary_missing (app_dl, str);
@@ -635,15 +606,8 @@ gs_flatpak_refresh_appstream (GsFlatpak *self, guint cache_age,
 {
 	gboolean ret;
 	gboolean something_changed = FALSE;
-	g_autoptr(AsProfileTask) ptask = NULL;
 	g_autoptr(GPtrArray) xremotes = NULL;
 
-	/* profile */
-	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
-				  "%s::refresh-appstream",
-				  gs_flatpak_get_id (self));
-	g_assert (ptask != NULL);
-
 	/* get remotes */
 	xremotes = flatpak_installation_list_remotes (self->installation,
 						      cancellable,
@@ -1282,16 +1246,8 @@ gs_plugin_refine_item_origin_hostname (GsFlatpak *self, GsApp *app,
 {
 	g_autoptr(FlatpakRemote) xremote = NULL;
 	g_autofree gchar *url = NULL;
-	g_autoptr(AsProfileTask) ptask = NULL;
 	g_autoptr(GError) error_local = NULL;
 
-	/* profile */
-	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
-				  "%s::refine-origin-hostname{%s}",
-				  gs_flatpak_get_id (self),
-				  gs_app_get_id (app));
-	g_assert (ptask != NULL);
-
 	/* already set */
 	if (gs_app_get_origin_hostname (app) != NULL)
 		return TRUE;
@@ -1377,7 +1333,6 @@ gs_plugin_refine_item_origin (GsFlatpak *self,
 			      GError **error)
 {
 	g_autofree gchar *ref_display = NULL;
-	g_autoptr(AsProfileTask) ptask = NULL;
 	g_autoptr(GError) local_error = NULL;
 	g_autoptr(GPtrArray) xremotes = NULL;
 
@@ -1390,10 +1345,6 @@ gs_plugin_refine_item_origin (GsFlatpak *self,
 		return TRUE;
 
 	/* ensure metadata exists */
-	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
-				  "%s::refine-origin",
-				  gs_flatpak_get_id (self));
-	g_assert (ptask != NULL);
 	if (!gs_refine_item_metadata (self, app, cancellable, error))
 		return FALSE;
 
@@ -1472,7 +1423,6 @@ gs_flatpak_refine_app_state (GsFlatpak *self,
 			      GError **error)
 {
 	g_autoptr(GPtrArray) xrefs = NULL;
-	g_autoptr(AsProfileTask) ptask = NULL;
 	g_autoptr(FlatpakInstalledRef) ref = NULL;
 	g_autoptr(GError) error_local = NULL;
 
@@ -1485,10 +1435,6 @@ gs_flatpak_refine_app_state (GsFlatpak *self,
 		return FALSE;
 
 	/* get apps and runtimes */
-	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
-				  "%s::refine-action",
-				  gs_flatpak_get_id (self));
-	g_assert (ptask != NULL);
 	ref = flatpak_installation_get_installed_ref (self->installation,
 						      gs_flatpak_app_get_ref_kind (app),
 						      gs_flatpak_app_get_ref_name (app),
@@ -1703,17 +1649,9 @@ gs_plugin_refine_item_metadata (GsFlatpak *self,
 	g_autofree gchar *contents = NULL;
 	g_autofree gchar *installation_path_str = NULL;
 	g_autofree gchar *install_path = NULL;
-	g_autoptr(AsProfileTask) ptask = NULL;
 	g_autoptr(GBytes) data = NULL;
 	g_autoptr(GFile) installation_path = NULL;
 
-	/* profile */
-	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
-				  "%s::refine-metadata{%s}",
-				  gs_flatpak_get_id (self),
-				  gs_app_get_id (app));
-	g_assert (ptask != NULL);
-
 	/* not applicable */
 	if (gs_app_get_kind (app) == AS_APP_KIND_SOURCE)
 		return TRUE;
@@ -1783,7 +1721,6 @@ gs_plugin_refine_item_size (GsFlatpak *self,
 	gboolean ret;
 	guint64 download_size = GS_APP_SIZE_UNKNOWABLE;
 	guint64 installed_size = GS_APP_SIZE_UNKNOWABLE;
-	g_autoptr(AsProfileTask) ptask = NULL;
 
 	/* not applicable */
 	if (gs_app_get_state (app) == AS_APP_STATE_AVAILABLE_LOCAL)
@@ -1831,10 +1768,6 @@ gs_plugin_refine_item_size (GsFlatpak *self,
 	}
 
 	/* just get the size of the app */
-	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
-				  "%s::refine-size",
-				  gs_flatpak_get_id (self));
-	g_assert (ptask != NULL);
 	if (!gs_plugin_refine_item_origin (self, app,
 					   cancellable, error))
 		return FALSE;
@@ -1911,14 +1844,6 @@ gs_flatpak_refine_appstream (GsFlatpak *self, GsApp *app, GError **error)
 {
 	AsApp *item;
 	const gchar *unique_id = gs_app_get_unique_id (app);
-	g_autoptr(AsProfileTask) ptask = NULL;
-
-	/* profile */
-	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
-				  "%s::refine-appstream{%s}",
-				  gs_flatpak_get_id (self),
-				  gs_app_get_id (app));
-	g_assert (ptask != NULL);
 
 	if (unique_id == NULL)
 		return TRUE;
@@ -1955,14 +1880,6 @@ gs_flatpak_refine_app (GsFlatpak *self,
 		       GError **error)
 {
 	AsAppState old_state = gs_app_get_state (app);
-	g_autoptr(AsProfileTask) ptask = NULL;
-
-	/* profile */
-	ptask = as_profile_start (gs_plugin_get_profile (self->plugin),
-				  "%s::refine{%s}",
-				  gs_flatpak_get_id (self),
-				  gs_app_get_id (app));
-	g_assert (ptask != NULL);
 
 	/* always do AppStream properties */
 	if (!gs_flatpak_refine_appstream (self, app, error))
