@@ -2,7 +2,7 @@
  *
  * Copyright (C) 2016 Joaquim Rocha <jrocha@endlessm.com>
  * Copyright (C) 2016-2018 Richard Hughes <richard@hughsie.com>
- * Copyright (C) 2017 Kalev Lember <klember@redhat.com>
+ * Copyright (C) 2017-2018 Kalev Lember <klember@redhat.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -109,13 +109,8 @@ gs_plugin_flatpak_add_installation (GsPlugin *plugin,
 				    GError **error)
 {
 	GsPluginData *priv = gs_plugin_get_data (plugin);
-	g_autoptr(AsProfileTask) ptask = NULL;
 	g_autoptr(GsFlatpak) flatpak = NULL;
 
-	ptask = as_profile_start_literal (gs_plugin_get_profile (plugin),
-					  "flatpak::add-installation");
-	g_assert (ptask != NULL);
-
 	/* create and set up */
 	flatpak = gs_flatpak_new (plugin, installation, GS_FLATPAK_FLAG_NONE);
 	if (!gs_flatpak_setup (flatpak, cancellable, error))
@@ -485,7 +480,7 @@ gs_plugin_download (GsPlugin *plugin, GsAppList *list,
 			return FALSE;
 		}
 	}
-	if (!flatpak_transaction_run (transaction, cancellable, error)) {
+	if (!gs_flatpak_transaction_run (transaction, cancellable, error)) {
 		gs_flatpak_error_convert (error);
 		return FALSE;
 	}
@@ -523,7 +518,7 @@ gs_plugin_app_remove (GsPlugin *plugin,
 		gs_flatpak_error_convert (error);
 		return FALSE;
 	}
-	if (!flatpak_transaction_run (transaction, cancellable, error)) {
+	if (!gs_flatpak_transaction_run (transaction, cancellable, error)) {
 		g_prefix_error (error, "failed to run transaction for %s: ", ref);
 		gs_flatpak_error_convert (error);
 		return FALSE;
@@ -659,7 +654,7 @@ gs_plugin_app_install (GsPlugin *plugin,
 	}
 
 	/* run transaction */
-	if (!flatpak_transaction_run (transaction, cancellable, error)) {
+	if (!gs_flatpak_transaction_run (transaction, cancellable, error)) {
 		g_prefix_error (error, "failed to run transaction for %s: ",
 				gs_app_get_unique_id (app));
 		gs_flatpak_error_convert (error);
@@ -709,7 +704,7 @@ gs_plugin_update_app (GsPlugin *plugin,
 		gs_flatpak_error_convert (error);
 		return FALSE;
 	}
-	if (!flatpak_transaction_run (transaction, cancellable, error)) {
+	if (!gs_flatpak_transaction_run (transaction, cancellable, error)) {
 		g_prefix_error (error, "failed to run transaction for %s: ", ref);
 		gs_flatpak_error_convert (error);
 		return FALSE;
@@ -899,7 +894,7 @@ gs_plugin_file_to_app (GsPlugin *plugin,
 		"application/vnd.flatpak.ref",
 		NULL };
 
-	/* does this match any of the mimetypes_bundle we support */
+	/* does this match any of the mimetypes we support */
 	content_type = gs_utils_get_content_type (file, cancellable, error);
 	if (content_type == NULL)
 		return FALSE;
