@@ -318,14 +318,22 @@ out:
 }
 
 static GsApp *
-app_from_modified_pkg_variant (GVariant *variant)
+app_from_modified_pkg_variant (GsPlugin *plugin, GVariant *variant)
 {
 	g_autoptr(GsApp) app = NULL;
 	const char *name;
 	const char *old_evr, *old_arch;
 	const char *new_evr, *new_arch;
+	g_autofree char *old_nevra = NULL;
+	g_autofree char *new_nevra = NULL;
 
 	g_variant_get (variant, "(us(ss)(ss))", NULL /* type*/, &name, &old_evr, &old_arch, &new_evr, &new_arch);
+	old_nevra = g_strdup_printf ("%s-%s-%s", name, old_evr, old_arch);
+	new_nevra = g_strdup_printf ("%s-%s-%s", name, new_evr, new_arch);
+
+	app = gs_plugin_cache_lookup (plugin, old_nevra);
+	if (app != NULL)
+		return g_steal_pointer (&app);
 
 	/* create new app */
 	app = gs_app_new (NULL);
@@ -342,21 +350,28 @@ app_from_modified_pkg_variant (GVariant *variant)
 	gs_app_set_update_version (app, new_evr);
 	gs_app_set_state (app, AS_APP_STATE_UPDATABLE);
 
-	g_debug ("!%s-%s-%s\n", name, old_evr, old_arch);
-	g_debug ("=%s-%s-%s\n", name, new_evr, new_arch);
+	g_debug ("!%s\n", old_nevra);
+	g_debug ("=%s\n", new_nevra);
 
+	gs_plugin_cache_add (plugin, old_nevra, app);
 	return g_steal_pointer (&app);
 }
 
 static GsApp *
-app_from_single_pkg_variant (GVariant *variant, gboolean addition)
+app_from_single_pkg_variant (GsPlugin *plugin, GVariant *variant, gboolean addition)
 {
 	g_autoptr(GsApp) app = NULL;
 	const char *name;
 	const char *evr;
 	const char *arch;
+	g_autofree char *nevra = NULL;
 
 	g_variant_get (variant, "(usss)", NULL /* type*/, &name, &evr, &arch);
+	nevra = g_strdup_printf ("%s-%s-%s", name, evr, arch);
+
+	app = gs_plugin_cache_lookup (plugin, nevra);
+	if (app != NULL)
+		return g_steal_pointer (&app);
 
 	/* create new app */
 	app = gs_app_new (NULL);
@@ -373,16 +388,17 @@ app_from_single_pkg_variant (GVariant *variant, gboolean addition)
 		gs_app_set_version (app, evr);
 		gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
 
-		g_debug ("+%s-%s-%s\n", name, evr, arch);
+		g_debug ("+%s\n", nevra);
 	} else {
 		/* removal */
 		gs_app_add_source (app, name);
 		gs_app_set_version (app, evr);
 		gs_app_set_state (app, AS_APP_STATE_UNAVAILABLE);
 
-		g_debug ("-%s-%s-%s\n", name, evr, arch);
+		g_debug ("-%s\n", nevra);
 	}
 
+	gs_plugin_cache_add (plugin, nevra, app);
 	return g_steal_pointer (&app);
 }
 
@@ -409,58 +425,6 @@ make_rpmostree_options_variant (gboolean reboot,
 	return g_variant_ref_sink (g_variant_dict_end (&dict));
 }
 
-static gboolean
-_download_only (GsPlugin *plugin, GCancellable *cancellable, GError **error)
-{
-	GsPluginData *priv = gs_plugin_get_data (plugin);
-	g_autofree gchar *transaction_address = NULL;
-	g_autoptr(GVariant) options = NULL;
-
-	options = make_rpmostree_options_variant (FALSE,  /* reboot */
-						  FALSE,  /* allow-downgrade */
-						  FALSE,  /* cache-only */
-						  TRUE,   /* download-only */
-						  FALSE,  /* skip-purge */
-						  FALSE,  /* no-pull-base */
-						  FALSE,  /* dry-run */
-						  FALSE); /* no-overrides */
-	if (!gs_rpmostree_os_call_upgrade_sync (priv->os_proxy,
-						options,
-						NULL /* fd list */,
-						&transaction_address,
-						NULL /* fd list out */,
-						cancellable,
-						error)) {
-		gs_utils_error_convert_gio (error);
-		return FALSE;
-	}
-
-	if (!gs_rpmostree_transaction_get_response_sync (priv->sysroot_proxy,
-							 transaction_address,
-							 cancellable,
-							 error)) {
-		gs_utils_error_convert_gio (error);
-		return FALSE;
-	}
-
-	return TRUE;
-}
-
-gboolean
-gs_plugin_download (GsPlugin *plugin,
-		    GsAppList *list,
-		    GCancellable *cancellable,
-		    GError **error)
-{
-	/* any are us? */
-	for (guint i = 0; i < gs_app_list_length (list); i++) {
-		GsApp *app = gs_app_list_index (list, i);
-		if (g_strcmp0 (gs_app_get_management_plugin (app), "rpm-ostree") == 0)
-			return _download_only (plugin, cancellable, error);
-	}
-	return TRUE;
-}
-
 gboolean
 gs_plugin_refresh (GsPlugin *plugin,
                    guint cache_age,
@@ -468,30 +432,68 @@ gs_plugin_refresh (GsPlugin *plugin,
                    GError **error)
 {
 	GsPluginData *priv = gs_plugin_get_data (plugin);
-	GVariantDict dict;
-	g_autofree gchar *transaction_address = NULL;
-	g_autoptr(GVariant) options = NULL;
 
-	g_variant_dict_init (&dict, NULL);
-	g_variant_dict_insert (&dict, "mode", "s", "check");
-	options = g_variant_ref_sink (g_variant_dict_end (&dict));
+	if (cache_age == G_MAXUINT)
+		return TRUE;
 
-	if (!gs_rpmostree_os_call_automatic_update_trigger_sync (priv->os_proxy,
-								 options,
-								 NULL,
-								 &transaction_address,
-								 cancellable,
-								 error)) {
-		gs_utils_error_convert_gio (error);
-		return FALSE;
+	{
+		g_autofree gchar *transaction_address = NULL;
+		g_autoptr(GVariant) options = NULL;
+
+		options = make_rpmostree_options_variant (FALSE,  /* reboot */
+		                                          FALSE,  /* allow-downgrade */
+		                                          FALSE,  /* cache-only */
+		                                          TRUE,   /* download-only */
+		                                          FALSE,  /* skip-purge */
+		                                          FALSE,  /* no-pull-base */
+		                                          FALSE,  /* dry-run */
+		                                          FALSE); /* no-overrides */
+		if (!gs_rpmostree_os_call_upgrade_sync (priv->os_proxy,
+		                                        options,
+		                                        NULL /* fd list */,
+		                                        &transaction_address,
+		                                        NULL /* fd list out */,
+		                                        cancellable,
+		                                        error)) {
+			gs_utils_error_convert_gio (error);
+			return FALSE;
+		}
+
+		if (!gs_rpmostree_transaction_get_response_sync (priv->sysroot_proxy,
+		                                                 transaction_address,
+		                                                 cancellable,
+		                                                 error)) {
+			gs_utils_error_convert_gio (error);
+			return FALSE;
+		}
 	}
 
-	if (!gs_rpmostree_transaction_get_response_sync (priv->sysroot_proxy,
-							 transaction_address,
-							 cancellable,
-							 error)) {
-		gs_utils_error_convert_gio (error);
-		return FALSE;
+	{
+		g_autofree gchar *transaction_address = NULL;
+		g_autoptr(GVariant) options = NULL;
+		GVariantDict dict;
+
+		g_variant_dict_init (&dict, NULL);
+		g_variant_dict_insert (&dict, "mode", "s", "check");
+		options = g_variant_ref_sink (g_variant_dict_end (&dict));
+
+		if (!gs_rpmostree_os_call_automatic_update_trigger_sync (priv->os_proxy,
+		                                                         options,
+		                                                         NULL,
+		                                                         &transaction_address,
+		                                                         cancellable,
+		                                                         error)) {
+			gs_utils_error_convert_gio (error);
+			return FALSE;
+		}
+
+		if (!gs_rpmostree_transaction_get_response_sync (priv->sysroot_proxy,
+		                                                 transaction_address,
+		                                                 cancellable,
+		                                                 error)) {
+			gs_utils_error_convert_gio (error);
+			return FALSE;
+		}
 	}
 
 	/* update UI */
@@ -573,7 +575,7 @@ gs_plugin_add_updates (GsPlugin *plugin,
 		/* iterate over all upgraded packages and add them */
 		g_variant_iter_init (&iter, upgraded);
 		while ((child = g_variant_iter_next_value (&iter)) != NULL) {
-			g_autoptr(GsApp) app = app_from_modified_pkg_variant (child);
+			g_autoptr(GsApp) app = app_from_modified_pkg_variant (plugin, child);
 			if (app != NULL)
 				gs_app_list_add (list, app);
 			g_variant_unref (child);
@@ -582,7 +584,7 @@ gs_plugin_add_updates (GsPlugin *plugin,
 		/* iterate over all downgraded packages and add them */
 		g_variant_iter_init (&iter, downgraded);
 		while ((child = g_variant_iter_next_value (&iter)) != NULL) {
-			g_autoptr(GsApp) app = app_from_modified_pkg_variant (child);
+			g_autoptr(GsApp) app = app_from_modified_pkg_variant (plugin, child);
 			if (app != NULL)
 				gs_app_list_add (list, app);
 			g_variant_unref (child);
@@ -591,7 +593,7 @@ gs_plugin_add_updates (GsPlugin *plugin,
 		/* iterate over all removed packages and add them */
 		g_variant_iter_init (&iter, removed);
 		while ((child = g_variant_iter_next_value (&iter)) != NULL) {
-			g_autoptr(GsApp) app = app_from_single_pkg_variant (child, FALSE);
+			g_autoptr(GsApp) app = app_from_single_pkg_variant (plugin, child, FALSE);
 			if (app != NULL)
 				gs_app_list_add (list, app);
 			g_variant_unref (child);
@@ -600,7 +602,7 @@ gs_plugin_add_updates (GsPlugin *plugin,
 		/* iterate over all added packages and add them */
 		g_variant_iter_init (&iter, added);
 		while ((child = g_variant_iter_next_value (&iter)) != NULL) {
-			g_autoptr(GsApp) app = app_from_single_pkg_variant (child, TRUE);
+			g_autoptr(GsApp) app = app_from_single_pkg_variant (plugin, child, TRUE);
 			if (app != NULL)
 				gs_app_list_add (list, app);
 			g_variant_unref (child);
@@ -839,7 +841,7 @@ gs_plugin_app_upgrade_download (GsPlugin *plugin,
 		return TRUE;
 
 	/* construct new refspec based on the distro version we're upgrading to */
-	new_refspec = g_strdup_printf ("ostree://fedora/%s/x86_64/workstation",
+	new_refspec = g_strdup_printf ("ostree://fedora/%s/x86_64/silverblue",
 	                               gs_app_get_version (app));
 
 	options = make_rpmostree_options_variant (FALSE,  /* reboot */
