@@ -79,7 +79,6 @@ typedef struct
 	GPtrArray		*modal_dialogs;
 	gulong			 search_changed_id;
 	gchar			*events_info_uri;
-	gboolean		 profile_mode;
 	gboolean		 in_mode_change;
 	GsPage			*page_last;
 } GsShellPrivate;
@@ -150,24 +149,6 @@ gs_shell_activate (GsShell *shell)
 	gtk_window_present (priv->main_window);
 }
 
-void
-gs_shell_profile_dump (GsShell *shell)
-{
-	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
-	if (priv->profile_mode) {
-		AsProfile *profile = gs_plugin_loader_get_profile (priv->plugin_loader);
-		as_profile_prune (profile, 5000);
-		as_profile_dump (profile);
-	}
-}
-
-void
-gs_shell_set_profile_mode (GsShell *shell, gboolean profile_mode)
-{
-	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
-	priv->profile_mode = profile_mode;
-}
-
 static void
 gs_shell_set_header_start_widget (GsShell *shell, GtkWidget *widget)
 {
@@ -2330,9 +2311,9 @@ gs_shell_dispose (GObject *object)
 	g_clear_object (&priv->header_start_widget);
 	g_clear_object (&priv->header_end_widget);
 	g_clear_object (&priv->page_last);
-	g_clear_pointer (&priv->pages, (GDestroyNotify) g_hash_table_unref);
-	g_clear_pointer (&priv->events_info_uri, (GDestroyNotify) g_free);
-	g_clear_pointer (&priv->modal_dialogs, (GDestroyNotify) g_ptr_array_unref);
+	g_clear_pointer (&priv->pages, g_hash_table_unref);
+	g_clear_pointer (&priv->events_info_uri, g_free);
+	g_clear_pointer (&priv->modal_dialogs, g_ptr_array_unref);
 
 	G_OBJECT_CLASS (gs_shell_parent_class)->dispose (object);
 }
